@@ -24,14 +24,20 @@
 #	matrix(ret[ret[,1] < ret[,2],], ncol = 2)
 #}
 
-zerodist <- function(obj, zero = 0.0) {
+zerodist <- function(obj, zero = 0.0, unique.ID = FALSE) {
 	if (!extends(class(obj), "SpatialPoints"))
 		stop("obj should be of, or extend, class SpatialPoints")
 	# calculates matrix with pairwise distances for 
 	# coordinate vectors x and y:
 	cc = coordinates(obj)
-	matrix(.Call("sp_zerodist", as.vector(t(cc)), ncol(cc), zero), 
+	zd = matrix(.Call("sp_zerodist", as.vector(t(cc)), ncol(cc), zero), 
 		ncol = 2, byrow = TRUE) + 1
+	if (unique.ID) {
+		id = 1:nrow(cc)
+		id[zd[,1]] = id[zd[,2]]
+		return(id)
+	} else
+		return(zd)
 }
 
 zerodist2 <- function (obj1, obj2, zero = 0) {
